<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Modo de avión activado</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Modo de avión desactivado</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avión</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Configuración do modo de avión</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avión</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Dispositivos meos</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Axustes do Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Acender</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Axustes do Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Conectado %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non conectado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Brilho</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Configuración da pantalla</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Configuración da pantalla</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Brilho</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Dom</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Lun</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Mér</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Xov</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Ven</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sáb</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Engadir disposición do teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tempo da data</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>formato 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>formato 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Axustes da hora</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Abrir o calendario</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Luns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mércores</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Xoves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Venres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>luns</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>martes</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>miércoles</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>jueves</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>viernes</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domingo</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Outros dispositivos</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Modo DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Configuración de modo No Disturbio</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Modo No Disturbio activado</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Modo No Disturbio desactivado</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Modo No Disturbio</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Comodidad ocular</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Comodidad ocular activada</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Comodidad ocular desactivada</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Configuración de pantalla</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Comodidad ocular</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Luz</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Oscuro</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Desactivar comodidad ocular</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Activar comodidad ocular</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Configuración de pantalla</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: Luz</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: Oscuro</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: Automático</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efecto visual</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Luz</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Negro</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Sen mensaxes</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Configuracións das notificacións</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificacións</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Desactivar o modo DND</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Activar o modo DND</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Notificación</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>A bordo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Alto rendemento</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Equilibrado</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Guarda de enerxía</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Rendemento equilibrado</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Enerxía</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Axustes de enerxía</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidade %1,  %2 minutos restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidade %1,%2h %3m restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Cargando %1, %2m até completar</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Cargando %1, %2h %3m até completar</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidade %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Cargando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidade %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidade %1, totalmente cargada</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capacidade %1, non se está cargando</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Batería</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Cargando, calculando o tempo de carga estimado</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Calculando o tempo restante de uso</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 minuto restante</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 hora e %2 minutos restantes</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Non se está cargando</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Cargado por completo</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Cargando, %1 minuto ata estar completo</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Cargando, %1 hora e %2 minutos ata estar completo</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Capacidade %1, %2 horas restantes</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 h restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Cargando %1, %2 h ata a carga completa</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Cargando, %1 h ata a carga completa</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Pechar sesión</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Axustes de enerxía</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Actualizar e apagar</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Actualizar e reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Cambiar de usuario</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>año</translation>
    </message>
    <message>
        <source>m</source>
        <translation>mes</translation>
    </message>
    <message>
        <source>d</source>
        <translation>dia</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation>xaneiro</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>febreiro</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>marzo</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>abril</translation>
    </message>
    <message>
        <source>May</source>
        <translation>maio</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>xuño</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>xullo</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>agosto</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>setembro</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>outubro</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>novembro</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dez</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Abrir o calendario</translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>tuesday</source>
        <translation>martes</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>miércoles</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation> jueves</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>viernes</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domingo</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuración sonora</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Desmutar</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mutar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuración sonora</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Non hai dispositivos de saída</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Nivel de volumen %1</translation>
    </message>
</context>
</TS>